diff --git a/routers/private/hook.go b/routers/private/hook.go
index 4bed86f38a..40edcd9c5a 100644
--- a/routers/private/hook.go
+++ b/routers/private/hook.go
@@ -668,7 +668,7 @@ func HookProcReceive(ctx *gitea_context.PrivateContext) {
 		return
 	}
 
-	ctx.JSON(http.StatusOK, private.HockProcReceiveResult{
+	ctx.JSON(http.StatusOK, private.HookProcReceiveResult{
 		Results: results,
 	})
 }
diff --git a/services/agit/agit.go b/services/agit/agit.go
index a89c255fe7..3fca844f91 100644
--- a/services/agit/agit.go
+++ b/services/agit/agit.go
@@ -20,7 +20,7 @@ import (
 )
 
 // ProcRecive handle proc receive work
-func ProcRecive(ctx *context.PrivateContext, opts *private.HookOptions) []private.HockProcReceiveRefResult {
+func ProcRecive(ctx *context.PrivateContext, opts *private.HookOptions) []private.HookProcReceiveRefResult {
 	// TODO: Add more options?
 	var (
 		topicBranch string
@@ -29,7 +29,7 @@ func ProcRecive(ctx *context.PrivateContext, opts *private.HookOptions) []privat
 		forcePush   bool
 	)
 
-	results := make([]private.HockProcReceiveRefResult, 0, len(opts.OldCommitIDs))
+	results := make([]private.HookProcReceiveRefResult, 0, len(opts.OldCommitIDs))
 	repo := ctx.Repo.Repository
 	gitRepo := ctx.Repo.GitRepo
 	ownerName := ctx.Repo.Repository.OwnerName
@@ -40,7 +40,7 @@ func ProcRecive(ctx *context.PrivateContext, opts *private.HookOptions) []privat
 
 	for i := range opts.OldCommitIDs {
 		if opts.NewCommitIDs[i] == git.EmptySHA {
-			results = append(results, private.HockProcReceiveRefResult{
+			results = append(results, private.HookProcReceiveRefResult{
 				OriginalRef: opts.RefFullNames[i],
 				OldOID:      opts.OldCommitIDs[i],
 				NewOID:      opts.NewCommitIDs[i],
@@ -50,7 +50,7 @@ func ProcRecive(ctx *context.PrivateContext, opts *private.HookOptions) []privat
 		}
 
 		if !strings.HasPrefix(opts.RefFullNames[i], git.PullRequestPrefix) {
-			results = append(results, private.HockProcReceiveRefResult{
+			results = append(results, private.HookProcReceiveRefResult{
 				IsNotMatched: true,
 				OriginalRef:  opts.RefFullNames[i],
 			})
@@ -71,7 +71,7 @@ func ProcRecive(ctx *context.PrivateContext, opts *private.HookOptions) []privat
 		}
 
 		if len(topicBranch) == 0 && len(curentTopicBranch) == 0 {
-			results = append(results, private.HockProcReceiveRefResult{
+			results = append(results, private.HookProcReceiveRefResult{
 				OriginalRef: opts.RefFullNames[i],
 				OldOID:      opts.OldCommitIDs[i],
 				NewOID:      opts.NewCommitIDs[i],
@@ -166,7 +166,7 @@ func ProcRecive(ctx *context.PrivateContext, opts *private.HookOptions) []privat
 
 			log.Trace("Pull request created: %d/%d", repo.ID, prIssue.ID)
 
-			results = append(results, private.HockProcReceiveRefResult{
+			results = append(results, private.HookProcReceiveRefResult{
 				Ref:         pr.GetGitRefName(),
 				OriginalRef: opts.RefFullNames[i],
 				OldOID:      git.EmptySHA,
@@ -194,7 +194,7 @@ func ProcRecive(ctx *context.PrivateContext, opts *private.HookOptions) []privat
 		}
 
 		if oldCommitID == opts.NewCommitIDs[i] {
-			results = append(results, private.HockProcReceiveRefResult{
+			results = append(results, private.HookProcReceiveRefResult{
 				OriginalRef: opts.RefFullNames[i],
 				OldOID:      opts.OldCommitIDs[i],
 				NewOID:      opts.NewCommitIDs[i],
@@ -212,7 +212,7 @@ func ProcRecive(ctx *context.PrivateContext, opts *private.HookOptions) []privat
 				})
 				return nil
 			} else if len(output) > 0 {
-				results = append(results, private.HockProcReceiveRefResult{
+				results = append(results, private.HookProcReceiveRefResult{
 					OriginalRef: oldCommitID,
 					OldOID:      opts.OldCommitIDs[i],
 					NewOID:      opts.NewCommitIDs[i],
@@ -255,7 +255,7 @@ func ProcRecive(ctx *context.PrivateContext, opts *private.HookOptions) []privat
 		notification.NotifyPullRequestSynchronized(pusher, pr)
 		isForcePush := comment != nil && comment.IsForcePush
 
-		results = append(results, private.HockProcReceiveRefResult{
+		results = append(results, private.HookProcReceiveRefResult{
 			OldOID:      oldCommitID,
 			NewOID:      opts.NewCommitIDs[i],
 			Ref:         pr.GetGitRefName(),
diff --git a/modules/private/hook.go b/modules/private/hook.go
index 4d0b5d22bf..fd864b1e6b 100644
--- a/modules/private/hook.go
+++ b/modules/private/hook.go
@@ -81,14 +81,14 @@ type HookPostReceiveBranchResult struct {
 	URL     string
 }
 
-// HockProcReceiveResult represents an individual result from ProcReceive
-type HockProcReceiveResult struct {
-	Results []HockProcReceiveRefResult
+// HookProcReceiveResult represents an individual result from ProcReceive
+type HookProcReceiveResult struct {
+	Results []HookProcReceiveRefResult
 	Err     string
 }
 
-// HockProcReceiveRefResult represents an individual result from ProcReceive
-type HockProcReceiveRefResult struct {
+// HookProcReceiveRefResult represents an individual result from ProcReceive
+type HookProcReceiveRefResult struct {
 	OldOID       string
 	NewOID       string
 	Ref          string
@@ -150,7 +150,7 @@ func HookPostReceive(ctx context.Context, ownerName, repoName string, opts HookO
 }
 
 // HookProcReceive proc-receive hook
-func HookProcReceive(ctx context.Context, ownerName, repoName string, opts HookOptions) (*HockProcReceiveResult, error) {
+func HookProcReceive(ctx context.Context, ownerName, repoName string, opts HookOptions) (*HookProcReceiveResult, error) {
 	reqURL := setting.LocalURL + fmt.Sprintf("api/internal/hook/proc-receive/%s/%s",
 		url.PathEscape(ownerName),
 		url.PathEscape(repoName),
@@ -170,7 +170,7 @@ func HookProcReceive(ctx context.Context, ownerName, repoName string, opts HookO
 	if resp.StatusCode != http.StatusOK {
 		return nil, errors.New(decodeJSONError(resp).Err)
 	}
-	res := &HockProcReceiveResult{}
+	res := &HookProcReceiveResult{}
 	_ = json.NewDecoder(resp.Body).Decode(res)
 
 	return res, nil